<!-- markdownlint-disable MD024 -->
<!-- markdownlint-disable MD013 -->
<!-- prettier-ignore-start -->
# Changelog

Changelog for `analphipy`

## Unreleased

See the fragment files in [changelog.d](https://github.com/usnistgov/analphipy/tree/main/changelog.d)

<!-- prettier-ignore-end -->

<!-- markdownlint-enable MD013 -->

<!-- scriv-insert-here -->

## v0.3.0 — 2023-08-04

### Added

- Package now available on conda-forge

### Changed

- Added better support for mypy/pyright type checking.

## v0.2.0 — 2023-05-04

### Removed

- Removed `cached_decorator` module.
- Removed `docfiller` module.

### Added

- Now use [module-utilities](https://pypi.org/project/module-utilities/) to
  handle caching and docfilling.

## v0.1.0 — 2023-04-24

### Changed

- Update package layout
- New linters via pre-commit
- Development env now handled by tox

## v0.0.6 - 2023-03-22

Full set of changes:
[`v0.0.5...v0.0.6`](https://github.com/usnistgov/analphipy/compare/v0.0.5...v0.0.6)

## v0.0.5 - 2023-03-22

Full set of changes:
[`v0.0.4...v0.0.5`](https://github.com/usnistgov/analphipy/compare/v0.0.4...v0.0.5)

## v0.0.4 - 2022-09-27

Full set of changes:
[`v0.0.3...v0.0.4`](https://github.com/usnistgov/analphipy/compare/v0.0.3...v0.0.4)

## v0.0.3 - 2022-09-26

Full set of changes:
[`v0.0.2...v0.0.3`](https://github.com/usnistgov/analphipy/compare/v0.0.2...v0.0.3)

## v0.0.2 - 2022-09-26

Full set of changes:
[`v0.0.1...v0.0.2`](https://github.com/usnistgov/analphipy/compare/v0.0.1...v0.0.2)

## v0.0.1 - 2022-09-26
